<?php
class main extends spController
{
	// 首页
	public function index(){
		// 这里的功能：
		// 1. 分页查找留言，通过$this->spArgs("page",1)获取到提交的页码，后面的1是默认值，在没有页面的时候就是1页
		// 2. findAll的参数，首先是NULL（无条件，查找全部）；"ctime DESC"是排序，这里按时间倒序；"gid,uname,title,ctime"是希望返回gid，用户名，标题和时间，而不获取contents（内容）以节省系统资源。
		// 3. 通过$this->results传递到模板上。
		$this->results = spClass("lib_guestbook")->spPager($this->spArgs("page",1),10)->findAll(NULL,"ctime DESC","gid,uname,title,ctime");
		
		// 这里的分页主要参考了网站分页教程内的代码。
		$this->pager = spClass("lib_guestbook")->spPager()->getPager();
	}
	
	// 查看留言内容
	public function view(){
		// 这里先判断是否传入了gid
		if( $gid = $this->spArgs("gid") ){
			// 查找guestbook表，获取留言信息
			$this->info = spClass("lib_guestbook")->find(array('gid'=>$gid));
		}else{
			// 无gid则直接跳转回首页
			$this->jump(spUrl("main","login"));
		}
	}
	// 退出登录
	public function logout(){
		// 这里是PHP.net关于删除SESSION的方法
		$_SESSION = array();
		if (isset($_COOKIE[session_name()])) {setcookie(session_name(), '', time()-42000, '/');}
		spClass('spAcl')->set("");
		session_destroy();
		// 跳转回首页
		$this->success("已退出，返回首页！", spUrl("main","index"));
	}
	// 显示用户登录框以及验证用户登录情况
	public function login(){
		$userObj = spClass("lib_user"); // 实例化lib_user类
		if( $uname = $this->spArgs("uname") ){ // 已经提交，这里开始进行登录验证
			$upass = $this->spArgs("upass");
			
			// 使用spVerifier进行第一次检查
			$rows = array('uname' => $uname, 'upass' => $upass);
			$results = $userObj->spVerifier($rows);
			
			if( false == $results ){ // 当spVerifier返回false的时候，则是表示已经通过验证，数据是合格的
			
				// 使用lib_user类中我们新建的userlogin方法来验证用户名和密码
				if( false == $userObj->userlogin($uname, $upass) ){
					// 登录失败，提示后跳转回登录页面
					$this->error("用户名/密码错误，请重新输入！", spUrl("main","login"));
					
				}else{
					// 成功登录，跳转。这里要进行判断一下：
					// 如果用户角色是GBADMIN（管理员）则跳转到admin/index的管理中心
					// 如果用户角色是GBUSER（普通会员）则跳转回首页
					$useracl = spClass("spAcl")->get(); // 通过acl的get可以获取到当前用户的角色标识
					if( "GBADMIN" == $useracl ){
						$this->success("登录成功，欢迎您，管理员！", spUrl("admin","index"));
					}else{
						$this->success("登录成功，欢迎您，尊敬的会员！", spUrl("main","index"));
					}
				}
			}else{
				// $results不是false，所以没有通过验证，错误信息是$results
				// dump($results);
				foreach($results as $item){ // 开始循环错误信息的规则，这里只有用户名
					// 每一个规则，都有可能返回多个错误信息，所以这里我们也循环$item来获取多个信息
					foreach($item as $msg){ 
						// 虽然我们使用了循环，但是这里我们只需要第一条出错信息就行。
						// 所以取到了第一条错误信息的时候，我们使用$this->error来提示并跳转
						$this->error($msg,spUrl("main","login"));
					}
				}
			}
		}
		// 这里是还没有填入用户名，所以将自动显示main_login.html的登录表单
	}
	
	// 发布留言，这里的权限是GBUSER才能执行
	public function post(){
		if( $title = $this->spArgs("title") ){
			// 已经提交，开始对数据进行验证
			$guestbookObj = spClass("lib_guestbook"); // 实例化留言对象
			
			// 这里直接验证全部的提交数据（$this->spArgs()获取全部提交数据）
			$results = $guestbookObj->spVerifier($this->spArgs());
			if( false == $results ){ // 当spVerifier返回false的时候，则是表示已经通过验证，数据是合格的
			
				// 调用lib_guestbook类的create来新增记录
				// 请注意！这里的create并非原来spModel的create，
				// 这个create函数是通过覆盖的方式，在lib_guestbook中已经重写了，以便加入新记录时间和用户名两个数据
				// 请查看lib_guestbook.php文件的create方法
				$guestbookObj->create($this->spArgs());
				$this->success("留言成功！", spUrl("main","index"));
			}else{
				// $results不是false，所以没有通过验证，错误信息是$results
				// dump($results);
				foreach($results as $item){
					// 每一个规则，都有可能返回多个错误信息，所以这里我们也循环$item来获取多个信息
					foreach($item as $msg){ 
						// 虽然我们使用了循环，但是这里我们只需要第一条出错信息就行。
						// 所以取到了第一条错误信息的时候，我们使用$this->error来提示并跳转
						$this->error($msg,spUrl("main","post"));
					}
				}
			}
		}
		// 这里是还没提交，则自动显示main_post.html的模板
	}
}	